pub struct Keypair(/* private fields */);Expand description
A vanilla Ed25519 key pair
Implementations
Sourceimpl Keypair
impl Keypair
Sourcepub const SECRET_KEY_LENGTH: usize = 32
pub const SECRET_KEY_LENGTH: usize = 32
Can be used for generating a Keypair without a dependency on rand types
Sourcepub fn new_from_array(secret_key: [u8; 32]) -> Keypair
pub fn new_from_array(secret_key: [u8; 32]) -> Keypair
Constructs a new Keypair using secret key bytes
Sourcepub fn try_from_base58_string(s: &str) -> Result<Keypair, Error>
pub fn try_from_base58_string(s: &str) -> Result<Keypair, Error>
Recovers a Keypair from a base58-encoded string
Sourcepub fn from_base58_string(s: &str) -> Keypair
pub fn from_base58_string(s: &str) -> Keypair
Recovers a Keypair from a base58-encoded string
Panics
Panics if given a malformed base58 string, or if the contents of the encoded string is invalid Keypair data.
Sourcepub fn to_base58_string(&self) -> String
pub fn to_base58_string(&self) -> String
Returns this Keypair as a base58-encoded string
Sourcepub fn secret_bytes(&self) -> &[u8; 32]
pub fn secret_bytes(&self) -> &[u8; 32]
Gets this Keypair’s secret key bytes
Sourcepub fn insecure_clone(&self) -> Keypair
pub fn insecure_clone(&self) -> Keypair
Allows Keypair cloning
Note that the Clone trait is intentionally unimplemented because making a
second copy of sensitive secret keys in memory is usually a bad idea.
Only use this in tests or when strictly required. Consider using std::sync::Arc<Keypair>
instead.